@@ -1564,12 +1564,14 @@ class BinaryPackage(object):
 
     def __setitem__(self, item, value):
         fn = path.join(self.work_dn, item)
-        open(fn, 'w').write("%s\n" % value.rstrip())
+        with open(fn, 'w') as f:
+            f.write("%s\n" % value.rstrip())
 
     def __getitem__(self, item):
         fn = path.join(self.work_dn, item)
         try:
-            return open(fn, 'r').read().strip()
+            with open(fn, 'r') as f:
+                return f.read().strip()
         except (IOError, OSError):
             return ""
 
